package VMOMI::CannotEnableVmcpForClusterReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
